
# define to enable features, undef otherwise
%ifnarch %{arm} aarch64
%global crashreporter 1
%endif

Name:    tomahawk
Version: 0.8.4
Release: 23%{?dist}
Summary: The Social Media Player

License: GPLv2+
URL:     http://tomahawk-player.org/
Source0: http://download.tomahawk-player.org/tomahawk-%{version}%{?pre}.tar.bz2

BuildRequires: boost-devel
BuildRequires: kdelibs4-devel
BuildRequires: liblastfm-devel >= 1.0
BuildRequires: pkgconfig(gnutls)
BuildRequires: pkgconfig(libattica) >= 0.4.0
BuildRequires: pkgconfig(libechonest) >= 2.2
BuildRequires: pkgconfig(libclucene-core) >= 2.3
BuildRequires: pkgconfig(libjreen) >= 1.1.1
BuildRequires: pkgconfig(liblucene++)
BuildRequires: pkgconfig(libsparsehash)
BuildRequires: pkgconfig(phonon) >= 4.5.0
BuildRequires: pkgconfig(qca2)
BuildRequires: pkgconfig(QtDBus) pkgconfig(QtGui) pkgconfig(QtNetwork) pkgconfig(QtXmlPatterns)
BuildRequires: pkgconfig(QtWebKit)
BuildRequires: pkgconfig(QJson) >= 0.8.1
BuildRequires: pkgconfig(taglib)
BuildRequires: pkgconfig(TelepathyQt4)
BuildRequires: quazip-devel
BuildRequires: qtkeychain-devel
BuildRequires: qtweetlib-devel >= 0.4
BuildRequires: websocketpp-devel

## upstreamable patches
# fix FindTaglib.cmake for taglib-1.10+
Patch50: tomahawk-0.8.4-taglib_version.patch

#define system_qxt 1
Patch0:  tomahawk-0.8.0-system_qxt.patch
%if 0%{?system_qxt}
# requires post recent qxt additions including qxtsslserver
BuildRequires: libqxt-devel >= 0.7
%else
Provides: bundled(libqxt) = 0.7
%endif

Requires: %{name}-libs%{?_isa} = %{version}-%{release}
%global libechonest_version %(pkg-config --modversion libechonest 2>/dev/null || echo 1.1.7)
Requires: libechonest%{?_isa} >= %{libechonest_version}
%global phonon_version %(pkg-config --modversion phonon 2>/dev/null || echo 4.5.0)
Requires: phonon%{?_isa} >= %{phonon_version}
Requires: qca-ossl%{?_isa}
Requires: qca-cyrus-sasl%{?_isa}


%description
Stop chasing your music across different machines, services and
websites. It's time to take the work out of "play". If the song you want
to listen to is in your local library, it just plays. If the song is on
a remote machine, it just plays. If the song is on the web, or available
from your subscription service, it just plays. By abstracting a piece
of content's metadata from its file location, users can easily share
playlists, listening history and more. It's sort of like Wonka Vision,
Tomahawk will reassemble it on the other side. OK, maybe that's not a
good analogy... but it's just as delicious.

%package libs
Summary: Runtime libraries for %{name}
## not strictly required, let's see if we can get away without it -- rex
#Requires: %{name} = %{version}-%{release}
%{?_qt4:Requires: qt4%{?_isa} >= %{_qt4_version}}
%description libs
%{summary}.

%package devel
Summary: Development files for %{name}
Requires: %{name}-libs%{?_isa} = %{version}-%{release}
%description devel
%{summary}.


%prep
%setup -q -n tomahawk-%{version}%{?pre}

%if 0%{?system_qxt}
%patch0 -p1 -b .system_qxt
rm -rv thirdparty/qxt
%endif

%patch50 -p1 -b .taglib_version


%build
mkdir %{_target_platform}
pushd %{_target_platform}
%{cmake_kde4} .. \
  -DBUILD_RELEASE:BOOL=ON \
  -DBUILD_WITH_QT4:BOOL=ON \
  -DCMAKE_BUILD_TYPE:STRING="RelWithDebInfo" \
  -DBUILD_HATCHET:BOOL=ON \
  -DWITH_CRASHREPORTER:BOOL=%{?crashreporter:ON}%{!?crashreporter:OFF}

make %{?_smp_mflags}
popd


%install
make install/fast DESTDIR=%{buildroot} -C %{_target_platform}

#unpackaged files (fixme?)
rm -fv %{buildroot}%{_datadir}/icons/hicolor/scalable/tomahawk.svg


%check
desktop-file-validate %{buildroot}%{_datadir}/applications/tomahawk.desktop

%files
%doc AUTHORS LICENSE.txt
%{_bindir}/tomahawk
%{_libdir}/libtomahawk_*.so
#if 0%{?crashreporter:1}
#{_libexecdir}/tomahawk_crash_reporter
#endif
%{_datadir}/applications/tomahawk.desktop
%{_datadir}/icons/hicolor/*/apps/tomahawk.*

%ldconfig_scriptlets libs

%files libs
%{_libdir}/libtomahawk.so.%{version}
%{_libdir}/libtomahawk-playdarapi.so.%{version}
%{_libdir}/libtomahawk-widgets.so.%{version}

%files devel
%{_includedir}/libtomahawk/
%{_libdir}/libtomahawk.so
%{_libdir}/libtomahawk-playdarapi.so
%{_libdir}/libtomahawk-widgets.so
%{_libdir}/cmake/Tomahawk/


%changelog
* Sat Jul 27 2019 Fedora Release Engineering <releng@fedoraproject.org> - 0.8.4-23
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Sun Feb 03 2019 Fedora Release Engineering <releng@fedoraproject.org> - 0.8.4-22
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Wed Jan 30 2019 Jonathan Wakely <jwakely@redhat.com> - 0.8.4-21
- Rebuilt for Boost 1.69

* Sat Jul 14 2018 Fedora Release Engineering <releng@fedoraproject.org> - 0.8.4-20
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Fri Feb 09 2018 Fedora Release Engineering <releng@fedoraproject.org> - 0.8.4-19
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Thu Jan 18 2018 Igor Gnatenko <ignatenkobrain@fedoraproject.org> - 0.8.4-18
- Remove obsolete scriptlets

* Thu Aug 03 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.8.4-17
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.8.4-16
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Fri Jul 21 2017 Kalev Lember <klember@redhat.com> - 0.8.4-15
- Rebuilt for Boost 1.64

* Mon May 15 2017 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.8.4-14
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_27_Mass_Rebuild

* Tue Feb 07 2017 Kalev Lember <klember@redhat.com> - 0.8.4-13
- Rebuilt for Boost 1.63

* Thu Sep 15 2016 Rex Dieter <rdieter@fedoraproject.org> - 0.8.4-12
- rebuild (websocketpp)

* Mon May 23 2016 Nikos Roussos <comzeradd@fedoraproject.org> 0.8.4-11
- Rebuild for qtkeychain new release

* Fri May 20 2016 Rex Dieter <rdieter@fedoraproject.org> - 0.8.4-10
- rebuild (qtkeychain)

* Fri Feb 05 2016 Fedora Release Engineering <releng@fedoraproject.org> - 0.8.4-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Tue Jan 19 2016 Jonathan Wakely <jwakely@redhat.com> - 0.8.4-8
- Rebuilt for Boost 1.60

* Fri Aug 28 2015 Jonathan Wakely <jwakely@redhat.com> 0.8.4-7
- Rebuilt for Boost 1.59

* Fri Aug 28 2015 Rex Dieter <rdieter@fedoraproject.org> 0.8.4-6
- fix FindTaglib.cmake for taglib-1.10+ (#1257906)

* Wed Jul 29 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.8.4-5
- Rebuilt for https://fedoraproject.org/wiki/Changes/F23Boost159

* Wed Jul 22 2015 David Tardon <dtardon@redhat.com> - 0.8.4-4
- rebuild for Boost 1.58

* Fri Jun 19 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.8.4-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Mon Jun 01 2015 Rex Dieter <rdieter@fedoraproject.org> 0.8.4-2
- rebuild (lucene++)

* Wed Apr 29 2015 Rex Dieter <rdieter@fedoraproject.org> 0.8.4-1
- 0.8.4

* Tue Jan 27 2015 Petr Machata <pmachata@redhat.com> - 0.8.2-3
- Rebuild for boost 1.57.0

* Tue Jan 27 2015 Petr Machata <pmachata@redhat.com> - 0.8.2-2
- Rebuild for boost 1.57.0

* Thu Nov 20 2014 Rex Dieter <rdieter@fedoraproject.org> 0.8.2-1
- tomahawk-0.8.2 (#1166418)

* Tue Nov 18 2014 Rex Dieter <rdieter@fedoraproject.org> 0.8.1-1
- tomahawk-0.8.1 (#1154274)

* Wed Nov 05 2014 Rex Dieter <rdieter@fedoraproject.org> 0.7.0-12
- rebuild (libechonest)

* Mon Aug 18 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.7.0-11
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sat Jun 28 2014 Rex Dieter <rdieter@fedoraproject.org> 0.7.0-10
- expclitly disable breakpad,crashreporter for aarch64 too

* Sun Jun 08 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.7.0-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Fri May 23 2014 Petr Machata <pmachata@redhat.com> - 0.7.0-8
- Rebuild for boost 1.55.0

* Tue May 13 2014 Rex Dieter <rdieter@fedoraproject.org> 0.7.0-7
- rebuild (jreen)

* Wed Mar 19 2014 Ville Skyttä <ville.skytta@iki.fi> - 0.7.0-6
- Use system qxt instead of bundled one

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.7.0-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Tue Jul 30 2013 Petr Machata <pmachata@redhat.com> - 0.7.0-4
- Rebuild for boost 1.54.0

* Wed May 22 2013 Rex Dieter <rdieter@fedoraproject.org> 0.7.0-3
- %%build: -DCMAKE_BUILD_TYPE=Release

* Wed May 22 2013 Rex Dieter <rdieter@fedoraproject.org> 0.7.0-2
- rebuild (libechonest-2.1.0)

* Fri May 10 2013 Rex Dieter <rdieter@fedoraproject.org> 0.7.0-1
- tomahawk-0.7.0

* Tue Mar 26 2013 Rex Dieter <rdieter@fedoraproject.org> 0.6.1-1
- 0.6.1

* Mon Feb 18 2013 Rex Dieter <rdieter@fedoraproject.org> 0.6.0-3
- tomahawk is FTBFS on ARM (#912361)

* Fri Feb 15 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.6.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Sat Jan 19 2013 Rex Dieter <rdieter@fedoraproject.org> 0.6.0-1
- 0.6.0 final

* Wed Jan 09 2013 Rex Dieter <rdieter@fedoraproject.org> 0.6.0-0.1.beta1
- 0.6.0beta1

* Sat Nov 24 2012 Rex Dieter <rdieter@fedoraproject.org> 0.5.5-3
- rebuild (qjson)

* Wed Sep 26 2012 Rex Dieter <rdieter@fedoraproject.org> 0.5.5-2
- Requires: qca-cyrus-sasl

* Thu Jul 26 2012 Rex Dieter <rdieter@fedoraproject.org> 0.5.5-1
- tomahawk-0.5.5

* Tue Jul 24 2012 Rex Dieter <rdieter@fedoraproject.org> 0.5.4-2
- rebuild

* Thu Jul 19 2012 Rex Dieter <rdieter@fedoraproject.org> 0.5.4-1
- tomahawk-0.5.4

* Sat Jul 14 2012 Rex Dieter <rdieter@fedoraproject.org> 0.5.2-2
- update scriptlet(s)

* Tue Jul 03 2012 Rex Dieter <rdieter@fedoraproject.org> 0.5.2-1
- tomahawk-0.5.2

* Wed Jun 20 2012 Rex Dieter <rdieter@fedoraproject.org> 0.4.2-2
- rebuild (attica)

* Mon Apr 23 2012 Rex Dieter <rdieter@fedoraproject.org> 0.4.2-1
- 0.4.2

* Wed Mar 07 2012 Magnus Tuominen <magnus.tuominen@gmail.com> 0.4.0-1
- 0.4.0
- no need for the tomahawk.protocol file any more

* Mon Jan 09 2012 Rex Dieter <rdieter@fedoraproject.org> 0.3.3-4
- update Summary (s/Music/Media/)

* Sun Jan 08 2012 Rex Dieter <rdieter@fedoraproject.org> 0.3.3-3
- make qca-ossl dep arch'd

* Fri Jan 06 2012 Rex Dieter <rdieter@fedoraproject.org> 0.3.3-2
- drop unused patch
- drop snapshotting comment

* Fri Jan 06 2012 Rex Dieter <rdieter@fedoraproject.org> 0.3.3-1
- 0.3.3

* Mon Nov 14 2011 Rex Dieter <rdieter@fedoraproject.org> 0.3.0-1
- 0.3.0

* Thu Sep 01 2011 Rex Dieter <rdieter@fedoraproject.org> 0.2.3-1
- 0.2.3

* Wed Aug 17 2011 Rex Dieter <rdieter@fedoraproject.org> 0.2.1-2
- unbundle jreen, BR: jreen-devel
- BR: boost-devel qca2-devel
- Requires: qca-ossl

* Tue Aug 16 2011 Rex Dieter <rdieter@fedoraproject.org> 0.2.1-1
- 0.2.1

* Tue Jun 14 2011 Rex Dieter <rdieter@fedoraproject.org> 0.1.0-3.20110614
- 20110614 snapshot
- bundle jreen/qtweetlib (for now)

* Thu Jun 02 2011 Rex Dieter <rdieter@fedoraproject.org> 0.1.0-2
- enable jreen, qtweeklib support
- add min runtime deps for qt,phonon,libechonest

* Wed Jun 01 2011 Rex Dieter <rdieter@fedoraproject.org> 0.1.0-1
- first try at 0.1.0

